==> haskell-strict-list-0.1.7.6-100-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-strict-list.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 strict-list
version:              0.1.7.6
visibility:           public
id:                   strict-list-0.1.7.6-B4Sv5HVCWFJ91hs6GuJR4O
key:                  strict-list-0.1.7.6-B4Sv5HVCWFJ91hs6GuJR4O
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/strict-list
synopsis:             Strict linked list
description:
    Implementation of strict linked list with care taken about stack.

category:             Data
abi:                  59ac93537d8b3782cf51157ada847a9c
exposed:              True
exposed-modules:      StrictList
hidden-modules:       StrictList.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/strict-list-0.1.7.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/strict-list-0.1.7.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/strict-list-0.1.7.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-strict-list
hs-libraries:         HSstrict-list-0.1.7.6-B4Sv5HVCWFJ91hs6GuJR4O
depends:
    base-4.17.2.1 deepseq-1.4.8.0
    hashable-1.4.5.0-DrXzgEMDRcV8gNOMGO5wPZ
    semigroupoids-6.0.1-I9bKNyn21Y9CEzT36Q6fxE

haddock-interfaces:   /usr/share/doc/haskell-strict-list/html/strict-list.haddock
haddock-html:         /usr/share/doc/haskell-strict-list/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-strict-list-0.1.7.6-101-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-strict-list.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 strict-list
version:              0.1.7.6
visibility:           public
id:                   strict-list-0.1.7.6-Iq6TnSf3Ijt9nZwXGzdZN
key:                  strict-list-0.1.7.6-Iq6TnSf3Ijt9nZwXGzdZN
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/strict-list
synopsis:             Strict linked list
description:
    Implementation of strict linked list with care taken about stack.

category:             Data
abi:                  27bffae174758cc1bca0f7e23bf13442
exposed:              True
exposed-modules:      StrictList
hidden-modules:       StrictList.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/strict-list-0.1.7.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/strict-list-0.1.7.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/strict-list-0.1.7.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-strict-list
hs-libraries:         HSstrict-list-0.1.7.6-Iq6TnSf3Ijt9nZwXGzdZN
depends:
    base-4.17.2.1 deepseq-1.4.8.0
    hashable-1.4.5.0-FUZ3820cmTgAr6H2g2EQN7
    semigroupoids-6.0.1-FFQydGbyHa3BSHQEfTGCRq

haddock-interfaces:   /usr/share/doc/haskell-strict-list/html/strict-list.haddock
haddock-html:         /usr/share/doc/haskell-strict-list/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
